@@ -31,38 +31,6 @@
 
 VIR_LOG_INIT("qemu.qemu_domainjob");
 
-static void *
-qemuJobDataAllocPrivateData(void)
-{
-    return g_new0(qemuDomainJobDataPrivate, 1);
-}
-
-
-static void *
-qemuJobDataCopyPrivateData(void *data)
-{
-    qemuDomainJobDataPrivate *ret = g_new0(qemuDomainJobDataPrivate, 1);
-
-    memcpy(ret, data, sizeof(qemuDomainJobDataPrivate));
-
-    return ret;
-}
-
-
-static void
-qemuJobDataFreePrivateData(void *data)
-{
-    g_free(data);
-}
-
-
-virDomainJobDataPrivateDataCallbacks qemuJobDataPrivateDataCallbacks = {
-    .allocPrivateData = qemuJobDataAllocPrivateData,
-    .copyPrivateData = qemuJobDataCopyPrivateData,
-    .freePrivateData = qemuJobDataFreePrivateData,
-};
-
-
 void
 qemuDomainJobSetStatsType(virDomainJobData *jobData,
                           qemuDomainJobStatsType type)
@@ -130,16 +98,15 @@ void
 qemuDomainEventEmitJobCompleted(virQEMUDriver *driver,
                                 virDomainObj *vm)
 {
-    qemuDomainObjPrivate *priv = vm->privateData;
     virObjectEvent *event;
     virTypedParameterPtr params = NULL;
     int nparams = 0;
     int type;
 
-    if (!priv->job.completed)
+    if (!vm->job->completed)
         return;
 
-    if (qemuDomainJobDataToParams(priv->job.completed, &type,
+    if (qemuDomainJobDataToParams(vm->job->completed, &type,
                                   &params, &nparams) < 0) {
         VIR_WARN("Could not get stats for completed job; domain %s",
                  vm->def->name);
@@ -160,8 +127,7 @@ qemuDomainObjRestoreAsyncJob(virDomainObj *vm,
                              virDomainJobStatus status,
                              unsigned long long allowedJobs)
 {
-    qemuDomainObjPrivate *priv = vm->privateData;
-    virDomainJobObj *job = &priv->job;
+    virDomainJobObj *job = vm->job;
 
     VIR_DEBUG("Restoring %s async job for domain %s",
               virDomainAsyncJobTypeToString(asyncJob), vm->def->name);
@@ -177,8 +143,8 @@ qemuDomainObjRestoreAsyncJob(virDomainObj *vm,
 
     qemuDomainObjSetAsyncJobMask(vm, allowedJobs);
 
-    job->current = virDomainJobDataInit(&qemuJobDataPrivateDataCallbacks);
-    qemuDomainJobSetStatsType(priv->job.current, statsType);
+    job->current = virDomainJobDataInit(&virQEMUDriverDomainJobConfig.jobDataPrivateCb);
+    qemuDomainJobSetStatsType(vm->job->current, statsType);
     job->current->operation = operation;
     job->current->status = status;
     job->current->started = started;
@@ -603,25 +569,24 @@ void
 qemuDomainObjSetJobPhase(virDomainObj *obj,
                          int phase)
 {
-    qemuDomainObjPrivate *priv = obj->privateData;
     unsigned long long me = virThreadSelfID();
 
-    if (!priv->job.asyncJob)
+    if (!obj->job->asyncJob)
         return;
 
     VIR_DEBUG("Setting '%s' phase to '%s'",
-              virDomainAsyncJobTypeToString(priv->job.asyncJob),
-              qemuDomainAsyncJobPhaseToString(priv->job.asyncJob, phase));
+              virDomainAsyncJobTypeToString(obj->job->asyncJob),
+              qemuDomainAsyncJobPhaseToString(obj->job->asyncJob, phase));
 
-    if (priv->job.asyncOwner != 0 &&
-        priv->job.asyncOwner != me) {
+    if (obj->job->asyncOwner != 0 &&
+        obj->job->asyncOwner != me) {
         VIR_WARN("'%s' async job is owned by thread %llu, API '%s'",
-                 virDomainAsyncJobTypeToString(priv->job.asyncJob),
-                 priv->job.asyncOwner,
-                 NULLSTR(priv->job.asyncOwnerAPI));
+                 virDomainAsyncJobTypeToString(obj->job->asyncJob),
+                 obj->job->asyncOwner,
+                 NULLSTR(obj->job->asyncOwnerAPI));
     }
 
-    priv->job.phase = phase;
+    obj->job->phase = phase;
     qemuDomainSaveStatus(obj);
 }
 
@@ -634,26 +599,25 @@ void
 qemuDomainObjStartJobPhase(virDomainObj *obj,
                            int phase)
 {
-    qemuDomainObjPrivate *priv = obj->privateData;
     unsigned long long me = virThreadSelfID();
 
-    if (!priv->job.asyncJob)
+    if (!obj->job->asyncJob)
         return;
 
     VIR_DEBUG("Starting phase '%s' of '%s' job",
-              qemuDomainAsyncJobPhaseToString(priv->job.asyncJob, phase),
-              virDomainAsyncJobTypeToString(priv->job.asyncJob));
+              qemuDomainAsyncJobPhaseToString(obj->job->asyncJob, phase),
+              virDomainAsyncJobTypeToString(obj->job->asyncJob));
 
-    if (priv->job.asyncOwner == 0) {
-        priv->job.asyncOwnerAPI = g_strdup(virThreadJobGet());
-    } else if (me != priv->job.asyncOwner) {
+    if (obj->job->asyncOwner == 0) {
+        obj->job->asyncOwnerAPI = g_strdup(virThreadJobGet());
+    } else if (me != obj->job->asyncOwner) {
         VIR_WARN("'%s' async job is owned by thread %llu, API '%s'",
-                 virDomainAsyncJobTypeToString(priv->job.asyncJob),
-                 priv->job.asyncOwner,
-                 NULLSTR(priv->job.asyncOwnerAPI));
+                 virDomainAsyncJobTypeToString(obj->job->asyncJob),
+                 obj->job->asyncOwner,
+                 NULLSTR(obj->job->asyncOwnerAPI));
     }
 
-    priv->job.asyncOwner = me;
+    obj->job->asyncOwner = me;
     qemuDomainObjSetJobPhase(obj, phase);
 }
 
@@ -662,453 +626,43 @@ void
 qemuDomainObjSetAsyncJobMask(virDomainObj *obj,
                              unsigned long long allowedJobs)
 {
-    qemuDomainObjPrivate *priv = obj->privateData;
-
-    if (!priv->job.asyncJob)
+    if (!obj->job->asyncJob)
         return;
 
-    priv->job.mask = allowedJobs | JOB_MASK(VIR_JOB_DESTROY);
+    obj->job->mask = allowedJobs | JOB_MASK(VIR_JOB_DESTROY);
 }
 
 void
 qemuDomainObjDiscardAsyncJob(virDomainObj *obj)
 {
-    qemuDomainObjPrivate *priv = obj->privateData;
-
-    if (priv->job.active == VIR_JOB_ASYNC_NESTED)
-        virDomainObjResetJob(&priv->job);
-    virDomainObjResetAsyncJob(&priv->job);
+    if (obj->job->active == VIR_JOB_ASYNC_NESTED)
+        virDomainObjResetJob(obj->job);
+    virDomainObjResetAsyncJob(obj->job);
     qemuDomainSaveStatus(obj);
 }
 
 void
 qemuDomainObjReleaseAsyncJob(virDomainObj *obj)
 {
-    qemuDomainObjPrivate *priv = obj->privateData;
-
     VIR_DEBUG("Releasing ownership of '%s' async job",
-              virDomainAsyncJobTypeToString(priv->job.asyncJob));
+              virDomainAsyncJobTypeToString(obj->job->asyncJob));
 
-    if (priv->job.asyncOwner != virThreadSelfID()) {
+    if (obj->job->asyncOwner != virThreadSelfID()) {
         VIR_WARN("'%s' async job is owned by thread %llu",
-                 virDomainAsyncJobTypeToString(priv->job.asyncJob),
-                 priv->job.asyncOwner);
+                 virDomainAsyncJobTypeToString(obj->job->asyncJob),
+                 obj->job->asyncOwner);
     }
-    priv->job.asyncOwner = 0;
-}
-
-/* Give up waiting for mutex after 30 seconds */
-#define QEMU_JOB_WAIT_TIME (1000ull * 30)
-
-/**
- * qemuDomainObjBeginJobInternal:
- * @obj: domain object
- * @job: virDomainJob to start
- * @asyncJob: virDomainAsyncJob to start
- * @nowait: don't wait trying to acquire @job
- *
- * Acquires job for a domain object which must be locked before
- * calling. If there's already a job running waits up to
- * QEMU_JOB_WAIT_TIME after which the functions fails reporting
- * an error unless @nowait is set.
- *
- * If @nowait is true this function tries to acquire job and if
- * it fails, then it returns immediately without waiting. No
- * error is reported in this case.
- *
- * Returns: 0 on success,
- *         -2 if unable to start job because of timeout or
- *            maxQueuedJobs limit,
- *         -1 otherwise.
- */
-static int ATTRIBUTE_NONNULL(1)
-qemuDomainObjBeginJobInternal(virDomainObj *obj,
-                              virDomainJob job,
-                              virDomainAgentJob agentJob,
-                              virDomainAsyncJob asyncJob,
-                              bool nowait)
-{
-    qemuDomainObjPrivate *priv = obj->privateData;
-    unsigned long long now;
-    unsigned long long then;
-    bool nested = job == VIR_JOB_ASYNC_NESTED;
-    const char *blocker = NULL;
-    const char *agentBlocker = NULL;
-    int ret = -1;
-    unsigned long long duration = 0;
-    unsigned long long agentDuration = 0;
-    unsigned long long asyncDuration = 0;
-    const char *currentAPI = virThreadJobGet();
-
-    VIR_DEBUG("Starting job: API=%s job=%s agentJob=%s asyncJob=%s "
-              "(vm=%p name=%s, current job=%s agentJob=%s async=%s)",
-              NULLSTR(currentAPI),
-              virDomainJobTypeToString(job),
-              virDomainAgentJobTypeToString(agentJob),
-              virDomainAsyncJobTypeToString(asyncJob),
-              obj, obj->def->name,
-              virDomainJobTypeToString(priv->job.active),
-              virDomainAgentJobTypeToString(priv->job.agentActive),
-              virDomainAsyncJobTypeToString(priv->job.asyncJob));
-
-    if (virTimeMillisNow(&now) < 0)
-        return -1;
-
-    priv->job.jobsQueued++;
-    then = now + QEMU_JOB_WAIT_TIME;
-
- retry:
-    if (job != VIR_JOB_ASYNC &&
-        job != VIR_JOB_DESTROY &&
-        priv->job.maxQueuedJobs &&
-        priv->job.jobsQueued > priv->job.maxQueuedJobs) {
-        goto error;
-    }
-
-    while (!nested && !virDomainNestedJobAllowed(&priv->job, job)) {
-        if (nowait)
-            goto cleanup;
-
-        VIR_DEBUG("Waiting for async job (vm=%p name=%s)", obj, obj->def->name);
-        if (virCondWaitUntil(&priv->job.asyncCond, &obj->parent.lock, then) < 0)
-            goto error;
-    }
-
-    while (!virDomainObjCanSetJob(&priv->job, job, agentJob)) {
-        if (nowait)
-            goto cleanup;
-
-        VIR_DEBUG("Waiting for job (vm=%p name=%s)", obj, obj->def->name);
-        if (virCondWaitUntil(&priv->job.cond, &obj->parent.lock, then) < 0)
-            goto error;
-    }
-
-    /* No job is active but a new async job could have been started while obj
-     * was unlocked, so we need to recheck it. */
-    if (!nested && !virDomainNestedJobAllowed(&priv->job, job))
-        goto retry;
-
-    if (obj->removing) {
-        char uuidstr[VIR_UUID_STRING_BUFLEN];
-
-        virUUIDFormat(obj->def->uuid, uuidstr);
-        virReportError(VIR_ERR_NO_DOMAIN,
-                       _("no domain with matching uuid '%s' (%s)"),
-                       uuidstr, obj->def->name);
-        goto cleanup;
-    }
-
-    ignore_value(virTimeMillisNow(&now));
-
-    if (job) {
-        virDomainObjResetJob(&priv->job);
-
-        if (job != VIR_JOB_ASYNC) {
-            VIR_DEBUG("Started job: %s (async=%s vm=%p name=%s)",
-                      virDomainJobTypeToString(job),
-                      virDomainAsyncJobTypeToString(priv->job.asyncJob),
-                      obj, obj->def->name);
-            priv->job.active = job;
-            priv->job.owner = virThreadSelfID();
-            priv->job.ownerAPI = g_strdup(virThreadJobGet());
-            priv->job.started = now;
-        } else {
-            VIR_DEBUG("Started async job: %s (vm=%p name=%s)",
-                      virDomainAsyncJobTypeToString(asyncJob),
-                      obj, obj->def->name);
-            virDomainObjResetAsyncJob(&priv->job);
-            priv->job.current = virDomainJobDataInit(priv->job.jobDataPrivateCb);
-            priv->job.current->status = VIR_DOMAIN_JOB_STATUS_ACTIVE;
-            priv->job.asyncJob = asyncJob;
-            priv->job.asyncOwner = virThreadSelfID();
-            priv->job.asyncOwnerAPI = g_strdup(virThreadJobGet());
-            priv->job.asyncStarted = now;
-            priv->job.current->started = now;
-        }
-    }
-
-    if (agentJob) {
-        virDomainObjResetAgentJob(&priv->job);
-
-        VIR_DEBUG("Started agent job: %s (vm=%p name=%s job=%s async=%s)",
-                  virDomainAgentJobTypeToString(agentJob),
-                  obj, obj->def->name,
-                  virDomainJobTypeToString(priv->job.active),
-                  virDomainAsyncJobTypeToString(priv->job.asyncJob));
-        priv->job.agentActive = agentJob;
-        priv->job.agentOwner = virThreadSelfID();
-        priv->job.agentOwnerAPI = g_strdup(virThreadJobGet());
-        priv->job.agentStarted = now;
-    }
-
-    if (virDomainTrackJob(job) && priv->job.cb)
-        priv->job.cb->saveStatusPrivate(obj);
-
-    return 0;
-
- error:
-    ignore_value(virTimeMillisNow(&now));
-    if (priv->job.active && priv->job.started)
-        duration = now - priv->job.started;
-    if (priv->job.agentActive && priv->job.agentStarted)
-        agentDuration = now - priv->job.agentStarted;
-    if (priv->job.asyncJob && priv->job.asyncStarted)
-        asyncDuration = now - priv->job.asyncStarted;
-
-    VIR_WARN("Cannot start job (%s, %s, %s) in API %s for domain %s; "
-             "current job is (%s, %s, %s) "
-             "owned by (%llu %s, %llu %s, %llu %s (flags=0x%lx)) "
-             "for (%llus, %llus, %llus)",
-             virDomainJobTypeToString(job),
-             virDomainAgentJobTypeToString(agentJob),
-             virDomainAsyncJobTypeToString(asyncJob),
-             NULLSTR(currentAPI),
-             obj->def->name,
-             virDomainJobTypeToString(priv->job.active),
-             virDomainAgentJobTypeToString(priv->job.agentActive),
-             virDomainAsyncJobTypeToString(priv->job.asyncJob),
-             priv->job.owner, NULLSTR(priv->job.ownerAPI),
-             priv->job.agentOwner, NULLSTR(priv->job.agentOwnerAPI),
-             priv->job.asyncOwner, NULLSTR(priv->job.asyncOwnerAPI),
-             priv->job.apiFlags,
-             duration / 1000, agentDuration / 1000, asyncDuration / 1000);
-
-    if (job) {
-        if (nested || virDomainNestedJobAllowed(&priv->job, job))
-            blocker = priv->job.ownerAPI;
-        else
-            blocker = priv->job.asyncOwnerAPI;
-    }
-
-    if (agentJob)
-        agentBlocker = priv->job.agentOwnerAPI;
-
-    if (errno == ETIMEDOUT) {
-        if (blocker && agentBlocker) {
-            virReportError(VIR_ERR_OPERATION_TIMEOUT,
-                           _("cannot acquire state change "
-                             "lock (held by monitor=%s agent=%s)"),
-                           blocker, agentBlocker);
-        } else if (blocker) {
-            virReportError(VIR_ERR_OPERATION_TIMEOUT,
-                           _("cannot acquire state change "
-                             "lock (held by monitor=%s)"),
-                           blocker);
-        } else if (agentBlocker) {
-            virReportError(VIR_ERR_OPERATION_TIMEOUT,
-                           _("cannot acquire state change "
-                             "lock (held by agent=%s)"),
-                           agentBlocker);
-        } else {
-            virReportError(VIR_ERR_OPERATION_TIMEOUT, "%s",
-                           _("cannot acquire state change lock"));
-        }
-        ret = -2;
-    } else if (priv->job.maxQueuedJobs &&
-               priv->job.jobsQueued > priv->job.maxQueuedJobs) {
-        if (blocker && agentBlocker) {
-            virReportError(VIR_ERR_OPERATION_FAILED,
-                           _("cannot acquire state change "
-                             "lock (held by monitor=%s agent=%s) "
-                             "due to max_queued limit"),
-                           blocker, agentBlocker);
-        } else if (blocker) {
-            virReportError(VIR_ERR_OPERATION_FAILED,
-                           _("cannot acquire state change "
-                             "lock (held by monitor=%s) "
-                             "due to max_queued limit"),
-                           blocker);
-        } else if (agentBlocker) {
-            virReportError(VIR_ERR_OPERATION_FAILED,
-                           _("cannot acquire state change "
-                             "lock (held by agent=%s) "
-                             "due to max_queued limit"),
-                           agentBlocker);
-        } else {
-            virReportError(VIR_ERR_OPERATION_FAILED, "%s",
-                           _("cannot acquire state change lock "
-                             "due to max_queued limit"));
-        }
-        ret = -2;
-    } else {
-        virReportSystemError(errno, "%s", _("cannot acquire job mutex"));
-    }
-
- cleanup:
-    priv->job.jobsQueued--;
-    return ret;
-}
-
-/*
- * obj must be locked before calling
- *
- * This must be called by anything that will change the VM state
- * in any way, or anything that will use the QEMU monitor.
- *
- * Successful calls must be followed by EndJob eventually
- */
-int qemuDomainObjBeginJob(virDomainObj *obj,
-                          virDomainJob job)
-{
-    if (qemuDomainObjBeginJobInternal(obj, job,
-                                      VIR_AGENT_JOB_NONE,
-                                      VIR_ASYNC_JOB_NONE, false) < 0)
-        return -1;
-    return 0;
-}
-
-/**
- * qemuDomainObjBeginAgentJob:
- *
- * Grabs agent type of job. Use if caller talks to guest agent only.
- *
- * To end job call qemuDomainObjEndAgentJob.
- */
-int
-qemuDomainObjBeginAgentJob(virDomainObj *obj,
-                           virDomainAgentJob agentJob)
-{
-    return qemuDomainObjBeginJobInternal(obj, VIR_JOB_NONE,
-                                         agentJob,
-                                         VIR_ASYNC_JOB_NONE, false);
-}
-
-int qemuDomainObjBeginAsyncJob(virDomainObj *obj,
-                               virDomainAsyncJob asyncJob,
-                               virDomainJobOperation operation,
-                               unsigned long apiFlags)
-{
-    qemuDomainObjPrivate *priv;
-
-    if (qemuDomainObjBeginJobInternal(obj, VIR_JOB_ASYNC,
-                                      VIR_AGENT_JOB_NONE,
-                                      asyncJob, false) < 0)
-        return -1;
-
-    priv = obj->privateData;
-    priv->job.current->operation = operation;
-    priv->job.apiFlags = apiFlags;
-    return 0;
-}
-
-int
-qemuDomainObjBeginNestedJob(virDomainObj *obj,
-                            virDomainAsyncJob asyncJob)
-{
-    qemuDomainObjPrivate *priv = obj->privateData;
-
-    if (asyncJob != priv->job.asyncJob) {
-        virReportError(VIR_ERR_INTERNAL_ERROR,
-                       _("unexpected async job %d type expected %d"),
-                       asyncJob, priv->job.asyncJob);
-        return -1;
-    }
-
-    if (priv->job.asyncOwner != virThreadSelfID()) {
-        VIR_WARN("This thread doesn't seem to be the async job owner: %llu",
-                 priv->job.asyncOwner);
-    }
-
-    return qemuDomainObjBeginJobInternal(obj,
-                                         VIR_JOB_ASYNC_NESTED,
-                                         VIR_AGENT_JOB_NONE,
-                                         VIR_ASYNC_JOB_NONE,
-                                         false);
-}
-
-/**
- * qemuDomainObjBeginJobNowait:
- *
- * @obj: domain object
- * @job: virDomainJob to start
- *
- * Acquires job for a domain object which must be locked before
- * calling. If there's already a job running it returns
- * immediately without any error reported.
- *
- * Returns: see qemuDomainObjBeginJobInternal
- */
-int
-qemuDomainObjBeginJobNowait(virDomainObj *obj,
-                            virDomainJob job)
-{
-    return qemuDomainObjBeginJobInternal(obj, job,
-                                         VIR_AGENT_JOB_NONE,
-                                         VIR_ASYNC_JOB_NONE, true);
-}
-
-/*
- * obj must be locked and have a reference before calling
- *
- * To be called after completing the work associated with the
- * earlier qemuDomainBeginJob() call
- */
-void
-qemuDomainObjEndJob(virDomainObj *obj)
-{
-    qemuDomainObjPrivate *priv = obj->privateData;
-    virDomainJob job = priv->job.active;
-
-    priv->job.jobsQueued--;
-
-    VIR_DEBUG("Stopping job: %s (async=%s vm=%p name=%s)",
-              virDomainJobTypeToString(job),
-              virDomainAsyncJobTypeToString(priv->job.asyncJob),
-              obj, obj->def->name);
-
-    virDomainObjResetJob(&priv->job);
-    if (virDomainTrackJob(job))
-        qemuDomainSaveStatus(obj);
-    /* We indeed need to wake up ALL threads waiting because
-     * grabbing a job requires checking more variables. */
-    virCondBroadcast(&priv->job.cond);
-}
-
-void
-qemuDomainObjEndAgentJob(virDomainObj *obj)
-{
-    qemuDomainObjPrivate *priv = obj->privateData;
-    virDomainAgentJob agentJob = priv->job.agentActive;
-
-    priv->job.jobsQueued--;
-
-    VIR_DEBUG("Stopping agent job: %s (async=%s vm=%p name=%s)",
-              virDomainAgentJobTypeToString(agentJob),
-              virDomainAsyncJobTypeToString(priv->job.asyncJob),
-              obj, obj->def->name);
-
-    virDomainObjResetAgentJob(&priv->job);
-    /* We indeed need to wake up ALL threads waiting because
-     * grabbing a job requires checking more variables. */
-    virCondBroadcast(&priv->job.cond);
-}
-
-void
-qemuDomainObjEndAsyncJob(virDomainObj *obj)
-{
-    qemuDomainObjPrivate *priv = obj->privateData;
-
-    priv->job.jobsQueued--;
-
-    VIR_DEBUG("Stopping async job: %s (vm=%p name=%s)",
-              virDomainAsyncJobTypeToString(priv->job.asyncJob),
-              obj, obj->def->name);
-
-    virDomainObjResetAsyncJob(&priv->job);
-    qemuDomainSaveStatus(obj);
-    virCondBroadcast(&priv->job.asyncCond);
+    obj->job->asyncOwner = 0;
 }
 
 void
 qemuDomainObjAbortAsyncJob(virDomainObj *obj)
 {
-    qemuDomainObjPrivate *priv = obj->privateData;
-
     VIR_DEBUG("Requesting abort of async job: %s (vm=%p name=%s)",
-              virDomainAsyncJobTypeToString(priv->job.asyncJob),
+              virDomainAsyncJobTypeToString(obj->job->asyncJob),
               obj, obj->def->name);
 
-    priv->job.abortJob = true;
+    obj->job->abortJob = true;
     virDomainObjBroadcast(obj);
 }
 
@@ -1116,35 +670,34 @@ int
 qemuDomainObjPrivateXMLFormatJob(virBuffer *buf,
                                  virDomainObj *vm)
 {
-    qemuDomainObjPrivate *priv = vm->privateData;
     g_auto(virBuffer) attrBuf = VIR_BUFFER_INITIALIZER;
     g_auto(virBuffer) childBuf = VIR_BUFFER_INIT_CHILD(buf);
-    virDomainJob job = priv->job.active;
+    virDomainJob job = vm->job->active;
 
     if (!virDomainTrackJob(job))
         job = VIR_JOB_NONE;
 
     if (job == VIR_JOB_NONE &&
-        priv->job.asyncJob == VIR_ASYNC_JOB_NONE)
+        vm->job->asyncJob == VIR_ASYNC_JOB_NONE)
         return 0;
 
     virBufferAsprintf(&attrBuf, " type='%s' async='%s'",
                       virDomainJobTypeToString(job),
-                      virDomainAsyncJobTypeToString(priv->job.asyncJob));
+                      virDomainAsyncJobTypeToString(vm->job->asyncJob));
 
-    if (priv->job.phase) {
+    if (vm->job->phase) {
         virBufferAsprintf(&attrBuf, " phase='%s'",
-                          qemuDomainAsyncJobPhaseToString(priv->job.asyncJob,
-                                                          priv->job.phase));
+                          qemuDomainAsyncJobPhaseToString(vm->job->asyncJob,
+                                                          vm->job->phase));
     }
 
-    if (priv->job.asyncJob != VIR_ASYNC_JOB_NONE) {
-        virBufferAsprintf(&attrBuf, " flags='0x%lx'", priv->job.apiFlags);
-        virBufferAsprintf(&attrBuf, " asyncStarted='%llu'", priv->job.asyncStarted);
+    if (vm->job->asyncJob != VIR_ASYNC_JOB_NONE) {
+        virBufferAsprintf(&attrBuf, " flags='0x%x'", vm->job->apiFlags);
+        virBufferAsprintf(&attrBuf, " asyncStarted='%llu'", vm->job->asyncStarted);
     }
 
-    if (priv->job.cb &&
-        priv->job.cb->formatJobPrivate(&childBuf, &priv->job, vm) < 0)
+    if (vm->job->cb &&
+        vm->job->cb->formatJobPrivate(&childBuf, vm->job, vm) < 0)
         return -1;
 
     virXMLFormatElement(buf, "job", &attrBuf, &childBuf);
@@ -1157,8 +710,7 @@ int
 qemuDomainObjPrivateXMLParseJob(virDomainObj *vm,
                                 xmlXPathContextPtr ctxt)
 {
-    qemuDomainObjPrivate *priv = vm->privateData;
-    virDomainJobObj *job = &priv->job;
+    virDomainJobObj *job = vm->job;
     VIR_XPATH_NODE_AUTORESTORE(ctxt)
     g_autofree char *tmp = NULL;
 
@@ -1174,7 +726,7 @@ qemuDomainObjPrivateXMLParseJob(virDomainObj *vm,
             return -1;
         }
         VIR_FREE(tmp);
-        priv->job.active = type;
+        vm->job->active = type;
     }
 
     if ((tmp = virXPathString("string(@async)", ctxt))) {
@@ -1186,11 +738,11 @@ qemuDomainObjPrivateXMLParseJob(virDomainObj *vm,
             return -1;
         }
         VIR_FREE(tmp);
-        priv->job.asyncJob = async;
+        vm->job->asyncJob = async;
 
         if ((tmp = virXPathString("string(@phase)", ctxt))) {
-            priv->job.phase = qemuDomainAsyncJobPhaseFromString(async, tmp);
-            if (priv->job.phase < 0) {
+            vm->job->phase = qemuDomainAsyncJobPhaseFromString(async, tmp);
+            if (vm->job->phase < 0) {
                 virReportError(VIR_ERR_INTERNAL_ERROR,
                                _("Unknown job phase %s"), tmp);
                 return -1;
@@ -1199,20 +751,19 @@ qemuDomainObjPrivateXMLParseJob(virDomainObj *vm,
         }
 
         if (virXPathULongLong("string(@asyncStarted)", ctxt,
-                              &priv->job.asyncStarted) == -2) {
+                              &vm->job->asyncStarted) == -2) {
             virReportError(VIR_ERR_INTERNAL_ERROR, "%s",
                            _("Invalid async job start"));
             return -1;
         }
     }
 
-    if (virXPathULongHex("string(@flags)", ctxt, &priv->job.apiFlags) == -2) {
-        virReportError(VIR_ERR_INTERNAL_ERROR, "%s", _("Invalid job flags"));
+    if (virXMLPropUInt(ctxt->node, "flags", 16, VIR_XML_PROP_NONE,
+                       &vm->job->apiFlags) < 0)
         return -1;
-    }
 
-    if (priv->job.cb &&
-        priv->job.cb->parseJobPrivate(ctxt, job, vm) < 0)
+    if (vm->job->cb &&
+        vm->job->cb->parseJobPrivate(ctxt, job, vm) < 0)
         return -1;
 
     return 0;
